@@ -16,7 +16,7 @@ from requests.adapters import HTTPAdapter
 
 __author__ = 'Fred Wang (taobao-pysdk@1e20.com)'
 __title__ = 'taobaopy'
-__version__ = '4.0.0'
+__version__ = '4.0.1'
 __license__ = 'BSD License'
 __copyright__ = 'Copyright 2013 Fred Wang'
 
@@ -38,7 +38,9 @@ RETRY_SUB_CODES = {
     'isp.top-remote-service-unavailable',
     'isp.top-remote-service-unavailable-tmall',
     'isp.top-remote-unknown-error',
+    'isp.top-remote-unknown-error-tmall',
     'isp.remote-connection-error',
+    'isp.remote-connection-error-tmall',
     'isp.item-update-service-error:GENERIC_FAILURE',
     'isp.item-update-service-error:IC_SYSTEM_NOT_READY_TRY_AGAIN_LATER',
     'ism.json-decode-error',
